#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ipynb
version:              0.1.0.1
visibility:           public
id:                   ipynb-0.1.0.1-3dBc3SkyC454G006DR5b3L
key:                  ipynb-0.1.0.1-3dBc3SkyC454G006DR5b3L
license:              BSD-3-Clause
copyright:            Copyright (C) 2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.

category:             Text
abi:                  52aafa7063d529bbb20d87c046f836b2
exposed:              True
exposed-modules:      Data.Ipynb
import-dirs:          /usr/lib/ghc-8.10.5/site-local/ipynb-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/ipynb-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/ipynb-0.1.0.1
hs-libraries:         HSipynb-0.1.0.1-3dBc3SkyC454G006DR5b3L
depends:
    aeson-1.5.6.0-IA546NaLWlLGqcowhw6tTs base-4.14.2.0
    base64-bytestring-1.2.0.1-Gn2QlQL7quxDmGBEoLUsKs
    bytestring-0.10.12.0 containers-0.6.4.1 text-1.2.4.1
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O

haddock-interfaces:   /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html:         /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

